==> scinumtools-2.7.5-py3-none-any.whl: scinumtools/dip/nodes/node_float.py <==
from typing import List

from ...units import Unit, UnitEnvironment
from .node_base import BaseNode
from .node_select import SelectNode
from ..solvers import NumericalSolver, FunctionSolver
from ..datatypes import FloatType, IntegerType

class FloatNode(BaseNode, SelectNode):
    keyword: str = 'float'
    value: float = None
    options: List = None
    value_expr: str = False
    dtype = float
    bits = 64

    def __init__(self, *args, **kwargs):
        self.options = []
        super().__init__(*args, **kwargs)
        
    @staticmethod
    def is_node(parser):
        if parser.keyword=='float':
             parser.part_dimension()
             parser.part_equal()
             if parser.is_parsed('part_equal'): # definition
                 parser.part_value()  
             else:
                 parser.defined = True  # declaration
             parser.part_units()    
             parser.part_comment()
             return FloatNode(parser)
         
    def set_value(self, value=None):
        """ Set value using value_raw or arbitrary value
        """
        if value is None and self.value_raw:
            self.value = FloatType(self.cast_value(), self.units_raw)
        elif value:
            self.value = FloatType(value, self.units_raw)
        else:
            self.value = None
            
    def parse(self, env):
        if self.value_fn: # Process function
            with FunctionSolver(env) as s:
                self.value_raw = s.solve(self.value_fn, self.units_raw)
        if self.value_expr: # Process expression
            with NumericalSolver(env) as s:
                self.value_raw = s.solve(self.value_expr, self.units_raw)
        # Testing validity of units
        if self.units_raw:
            with UnitEnvironment(env.units):
                Unit(self.units_raw)
        return None

==> scinumtools-2.10.0-py3-none-any.whl: scinumtools/dip/nodes/node_float.py <==
from typing import List

from ...units import Unit, UnitEnvironment
from .node_base import BaseNode
from .node_select import SelectNode
from ..solvers import NumericalSolver, FunctionSolver
from ..datatypes import FloatType, IntegerType

class FloatNode(BaseNode, SelectNode):
    keyword: str = 'float'
    value: float = None
    options: List = None
    value_expr: str = False
    tags: list = None
    description: str = None
    dtype = float
    bits = 64

    def __init__(self, *args, **kwargs):
        self.options = []
        super().__init__(*args, **kwargs)
        
    @staticmethod
    def is_node(parser):
        if parser.keyword=='float':
             parser.part_dimension()
             parser.part_equal()
             if parser.is_parsed('part_equal'): # definition
                 parser.part_value()  
             else:
                 parser.defined = True  # declaration
             parser.part_units()    
             parser.part_comment()
             return FloatNode(parser)
         
    def set_value(self, value=None):
        """ Set value using value_raw or arbitrary value
        """
        precision = self.dtype_prop[0] if self.dtype_prop[0] else FloatType.precision
        if value is None and self.value_raw:
            self.value = FloatType(self.cast_value(), self.units_raw, precision=precision)
        elif value:
            self.value = FloatType(value, self.units_raw, precision=precision)
        else:
            self.value = None
            
    def parse(self, env):
        if self.value_fn: # Process function
            with FunctionSolver(env) as s:
                self.value_raw = s.solve(self.value_fn, self.units_raw)
        if self.value_expr: # Process expression
            with NumericalSolver(env) as s:
                self.value_raw = s.solve(self.value_expr, self.units_raw)
        # Testing validity of units
        if self.units_raw:
            with UnitEnvironment(env.units):
                Unit(self.units_raw)
        return None
